@@ -458,9 +458,11 @@ class Excel2Reference:
 
         return result
 
-    def main(self, excel=None):
+    def main(self, excel=None, excel_sheet=None):
         if self.result["code"] != "OK":
             return self.result
+        if excel_sheet is not None:
+            self.excel_sheet = excel_sheet
         self.json_directory += basename(excel)
         makedirs(self.json_directory, exist_ok=True)
         print(self.json_directory)
