@@ -31,6 +31,7 @@ class JSON2EDCLineageFiles:
         self.nr_attribute_associations = 0
         self.excel_file = None
         self.resource_items = None
+        self.ref_directory = None
         self.get_settings(configuration_file=configuration_file)
         makedirs(self.output_directory, exist_ok=True)
 
@@ -82,6 +83,10 @@ class JSON2EDCLineageFiles:
                 if self.excel_file is not None:
                     self.json_directory = path.join(self.json_directory, self.excel_file)
                 self.resource_items = data["resource_items"]
+                if "ref_directory" in data:
+                    self.ref_directory = data["ref_directory"]
+                else:
+                    self.ref_directory = self.output_directory
                 # print("resource_items:", self.resource_items)
         except FileNotFoundError or IOError as e:
             result = messages.message["main_config_not_found"]
@@ -137,12 +142,14 @@ class JSON2EDCLineageFiles:
         # get info from REF files, generated out of the Excel by excel2references
         src_ref = self.get_dataset_ref("source", source_name)
         if src_ref is None:
+            print("Could not find source reference for >%s<" % source_name)
             src_path = "NONE://" + source_name
         else:
             src_edc_datasource, src_prefix, src_layer, src_zone = self.get_datasource_ref(src_ref["src_zone"])
             src_path = src_edc_datasource + "://" + src_prefix + src_ref["src_zone"] + "/" + source_name
         tgt_ref = self.get_dataset_ref("target", target_name)
         if tgt_ref is None:
+            print("Could not find target reference for >%s<" % target_name)
             tgt_path = "NONE://" + target_name
         else:
             tgt_edc_datasource, tgt_prefix, tgt_layer, tgt_zone = self.get_datasource_ref(tgt_ref["tgt_zone"])
@@ -176,7 +183,7 @@ class JSON2EDCLineageFiles:
     def get_dataset_ref(self, src_or_tgt, dataset_name):
         file = self.find_latest_ref_file(src_or_tgt)
         if file is None:
-            print("Could not find a REF file for >%s<" % src_or_tgt)
+            print("Could not find a dataset REF file for >%s< >%s<" % (src_or_tgt, dataset_name))
             return None
         # print("Using ref file:", file)
         data = None
@@ -192,10 +199,11 @@ class JSON2EDCLineageFiles:
                     return entry
         else:
             print("Incorrect src_or_tgt:", src_or_tgt)
+        print("get_dataset_ref: Could not find reference for >%s< >%s<" % (src_or_tgt, dataset_name))
         return None
 
     def find_latest_ref_file(self, src_or_tgt):
-        search_for_files = self.output_directory + "/" + "20*--REF_-_data-sources-" + src_or_tgt + "*dataset.json"
+        search_for_files = self.ref_directory + "/" + "20*--REF_-_data-sources-" + src_or_tgt + "*dataset.json"
         # print("Looking for REF files with search >%s<" % search_for_files)
         list_of_files = glob(search_for_files)
         if list_of_files is not None and len(list_of_files) > 0:
@@ -263,6 +271,8 @@ class JSON2EDCLineageFiles:
         # get info from REF files, generated out of the Excel by excel2references
         src_ref = self.get_dataset_ref("source", source_dataset)
         if src_ref is None:
+            print("Could not find source dataset reference for attribute >%s< in source >%s<"
+                  % (source_attribute, source_dataset))
             src_path = "NONE://" + source_dataset + "/" + source_attribute
         else:
             src_edc_datasource, src_prefix, src_layer, src_zone = self.get_datasource_ref(src_ref["src_zone"])
@@ -270,6 +280,8 @@ class JSON2EDCLineageFiles:
                        + "/" + source_dataset + "/" + source_attribute
         tgt_ref = self.get_dataset_ref("target", target_dataset)
         if tgt_ref is None:
+            print("Could not find target dataset reference for attribute >%s< in target >%s<"
+                  % (target_attribute, target_dataset))
             tgt_path = "NONE://" + target_dataset + "/" + target_attribute
         else:
             tgt_edc_datasource, tgt_prefix, tgt_layer, tgt_zone = self.get_datasource_ref(tgt_ref["tgt_zone"])
