@@ -103,9 +103,14 @@ message = {
         , "level": "ERROR"
         , "info": "none"
     }, "target_attribute_not_in_target_entities": {
-        "code": "EMI-SRCH-002"
+        "code": "EMI-SRCH-003"
         , "message": "Target attribute in not part of any target entity"
         , "level": "ERROR"
         , "info": "none"
+    }, "target_entity_not_found": {
+        "code": "EMI-SRCH-004"
+        , "message": "Target entity with specified UUID could not be found in any JSON entity file"
+        , "level": "ERROR"
+        , "info": "none"
     }
 }
